<!-- $Revision: 5338 $ -->
<HTML>
  <HEAD>
    <TITLE>&Uacute;častn&iacute;ci konference <MM-List-Name></TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
    <TABLE WIDTH="100%" COLS="1" BORDER="0" CELLSPACING="4" CELLPADDING="5">
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	  <B><FONT COLOR="#000000" SIZE="+1"> &Uacute;častn&iacute;ci konference <MM-List-Name>
		</FONT></B>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" ALIGN="CENTER">

          <P align = "right"> <MM-lang-form-start><MM-displang-box>
                       <MM-list-langs><MM-form-end></p>        
	    
	  <P>
              Klikněte na svou adresu. Vstoup&iacute;te t&iacute;m na str&aacute;nku na kter&eacute; si
můžete libovolně konfigurovat sv&eacute; &uacute;častnick&eacute; konto. <br>
<I>(&Uacute;častn&iacute;ci v z&aacute;vork&aacute;ch maj&iacute; zak&aacute;z&aacute;no doručov&aacute;n&iacute; po&scaron;ty. )</I></P>
	</TD>
      </TR>
      <TR WIDTH="100%" VALIGN="top">
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Reg-Users>
		  běžn&yacute;ch &uacute;častn&iacute;ků konference <MM-List-Name>:</FONT></B>
	  </center>
	</TD>
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Digesters> &Uacute;častn&iacute;ků konference 
<MM-List-Name> využ&iacute;v&aacute; digest:</FONT></B> 
	  </center>
	</TD>
      </TR>
      <TR VALIGN="top">
	<td>
	  <P><MM-Regular-Users>
	</td>
	<td>
	  <P><MM-Digest-Users>
	</td>
      </tr>
    </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
